========================================
Data Camp Statistical Thinking utilities
========================================


.. image:: https://img.shields.io/pypi/v/dc_stat_think.svg
        :target: https://pypi.python.org/pypi/dc_stat_think

.. image:: https://img.shields.io/travis/justinbois/dc_stat_think.svg
        :target: https://travis-ci.org/justinbois/dc_stat_think

.. image:: https://pyup.io/repos/github/justinbois/dc_stat_think/shield.svg
     :target: https://pyup.io/repos/github/justinbois/dc_stat_think/
     :alt: Updates


Utility functions used in the DataCamp Statistical Thinking courses.


* Free software: MIT license


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template and then modified.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
